Module: Apex::Version

Defined in:
lib/apex/version.rb

Overview

Apex Ruby binding version.

This is the version of the Ruby gem, not the underlying Apex C library. The C library version can be queried via the C API once bound.

Constant Summary collapse

VERSION =

Current gem version.

"1.0.11"